@@ -5,22 +5,16 @@
 /*! Parsing of packed resources data blobs. */
 
 use {
-    super::data::{
-        BlobInteriorPadding, BlobSectionField, Resource, ResourceField, ResourceFlavor, HEADER_V3,
+    crate::{
+        resource::Resource,
+        serialization::{BlobInteriorPadding, BlobSectionField, ResourceField, HEADER_V3},
     },
     byteorder::{LittleEndian, ReadBytesExt},
-    std::{
-        borrow::Cow,
-        collections::{HashMap, HashSet},
-        convert::TryFrom,
-        ffi::OsStr,
-        io::{Cursor, Read},
-        path::Path,
-    },
+    std::{borrow::Cow, collections::HashMap, io::Cursor, path::Path},
 };
 
 #[cfg(unix)]
-use std::os::unix::ffi::OsStrExt;
+use std::{ffi::OsStr, os::unix::ffi::OsStrExt};
 #[cfg(windows)]
 use {std::ffi::OsString, std::os::windows::ffi::OsStringExt, std::path::PathBuf};
 
@@ -39,8 +33,10 @@ struct BlobSectionReadState {
     interior_padding: BlobInteriorPadding,
 }
 
-pub type PythonPackageResources<'a> = HashMap<&'a str, &'a [u8]>;
-
+/// An iterator over an actively parsed packed resources data structure.
+///
+/// The iterator emits [Resource] instances. The index data for a given resource is
+/// not read or validated until the iterator attempts to deserialize it.
 pub struct ResourceParserIterator<'a> {
     done: bool,
     data: &'a [u8],
@@ -123,29 +119,16 @@ impl<'a> ResourceParserIterator<'a> {
                     current_resource = Resource::default();
                     current_resource_name = None;
                 }
-
                 ResourceField::EndOfEntry => {
-                    let res = if let Some(name) = current_resource_name {
+                    let res = if current_resource_name.is_some() {
                         Ok(Some(current_resource))
                     } else {
                         Err("resource name field is required")
                     };
 
-                    current_resource = Resource::default();
-                    current_resource_name = None;
-
                     return res;
                 }
-                ResourceField::Flavor => {
-                    let flavor = self
-                        .reader
-                        .read_u8()
-                        .map_err(|_| "failed reading flavor value")?;
-
-                    current_resource.flavor = ResourceFlavor::try_from(flavor)?;
-                }
-
-                ResourceField::ModuleName => {
+                ResourceField::Name => {
                     let l = self
                         .reader
                         .read_u16::<LittleEndian>()
@@ -159,11 +142,11 @@ impl<'a> ResourceParserIterator<'a> {
                     current_resource_name = Some(name);
                     current_resource.name = Cow::Borrowed(name);
                 }
-                ResourceField::IsPackage => {
-                    current_resource.is_package = true;
+                ResourceField::IsPythonPackage => {
+                    current_resource.is_python_package = true;
                 }
-                ResourceField::IsNamespacePackage => {
-                    current_resource.is_namespace_package = true;
+                ResourceField::IsPythonNamespacePackage => {
+                    current_resource.is_python_namespace_package = true;
                 }
                 ResourceField::InMemorySource => {
                     let l = self
@@ -448,20 +431,20 @@ impl<'a> ResourceParserIterator<'a> {
                     current_resource.relative_path_distribution_resources = Some(resources);
                 }
 
-                ResourceField::IsModule => {
-                    current_resource.is_module = true;
+                ResourceField::IsPythonModule => {
+                    current_resource.is_python_module = true;
                 }
 
-                ResourceField::IsBuiltinExtensionModule => {
-                    current_resource.is_builtin_extension_module = true;
+                ResourceField::IsPythonBuiltinExtensionModule => {
+                    current_resource.is_python_builtin_extension_module = true;
                 }
 
-                ResourceField::IsFrozenModule => {
-                    current_resource.is_frozen_module = true;
+                ResourceField::IsPythonFrozenModule => {
+                    current_resource.is_python_frozen_module = true;
                 }
 
-                ResourceField::IsExtensionModule => {
-                    current_resource.is_extension_module = true;
+                ResourceField::IsPythonExtensionModule => {
+                    current_resource.is_python_extension_module = true;
                 }
 
                 ResourceField::IsSharedLibrary => {
@@ -518,6 +501,14 @@ impl<'a> Iterator for ResourceParserIterator<'a> {
     }
 }
 
+/// Parse a packed resources data structure.
+///
+/// The data structure is parsed lazily via an iterator that emits reconstructed
+/// [Resource] instances.
+///
+/// Performance note: we once attempted to switch to anyhow for error handling and
+/// this decreased performance by ~15%. Given the performance sensitivity of this
+/// code, we need to keep error handling primitive.
 pub fn load_resources<'a>(data: &'a [u8]) -> Result<ResourceParserIterator<'a>, &'static str> {
     if data.len() < HEADER_V3.len() {
         return Err("error reading 8 byte header");
@@ -659,9 +650,10 @@ fn load_resources_v3<'a>(data: &'a [u8]) -> Result<ResourceParserIterator<'a>, &
 mod tests {
     use {
         super::*,
-        crate::data::{BlobInteriorPadding, Resource},
-        crate::writer::write_packed_resources_v3,
-        std::collections::BTreeMap,
+        crate::{
+            resource::Resource, serialization::BlobInteriorPadding,
+            writer::write_packed_resources_v3,
+        },
     };
 
     #[test]
@@ -1381,10 +1373,9 @@ mod tests {
         );
 
         let resource = Resource {
-            flavor: ResourceFlavor::Module,
             name: Cow::from("module"),
-            is_package: true,
-            is_namespace_package: true,
+            is_python_package: true,
+            is_python_namespace_package: true,
             in_memory_source: Some(Cow::from(b"source".to_vec())),
             in_memory_bytecode: Some(Cow::from(b"bytecode".to_vec())),
             in_memory_bytecode_opt1: Some(Cow::from(b"bytecodeopt1".to_vec())),
@@ -1401,10 +1392,10 @@ mod tests {
             relative_path_extension_module_shared_library: Some(Cow::from(Path::new("em_path"))),
             relative_path_package_resources: Some(relative_path_resources),
             relative_path_distribution_resources: Some(relative_path_distribution),
-            is_module: true,
-            is_builtin_extension_module: true,
-            is_frozen_module: true,
-            is_extension_module: true,
+            is_python_module: true,
+            is_python_builtin_extension_module: true,
+            is_python_frozen_module: true,
+            is_python_extension_module: true,
             is_shared_library: true,
             is_utf8_filename_data: true,
             file_executable: true,
@@ -1423,9 +1414,8 @@ mod tests {
 
         let entry = &resources[0];
 
-        assert_eq!(entry.flavor, ResourceFlavor::Module);
-        assert!(entry.is_package);
-        assert!(entry.is_namespace_package);
+        assert!(entry.is_python_package);
+        assert!(entry.is_python_namespace_package);
         assert_eq!(entry.in_memory_source.as_ref().unwrap().as_ref(), b"source");
         assert_eq!(
             entry.in_memory_bytecode.as_ref().unwrap().as_ref(),
@@ -1510,10 +1500,10 @@ mod tests {
             distribution.get("resource.txt"),
             Some(&Cow::Borrowed(Path::new("package/resource.txt")))
         );
-        assert!(entry.is_module);
-        assert!(entry.is_builtin_extension_module);
-        assert!(entry.is_frozen_module);
-        assert!(entry.is_extension_module);
+        assert!(entry.is_python_module);
+        assert!(entry.is_python_builtin_extension_module);
+        assert!(entry.is_python_frozen_module);
+        assert!(entry.is_python_extension_module);
         assert!(entry.is_shared_library);
         assert!(entry.is_utf8_filename_data);
         assert!(entry.file_executable);
@@ -1531,14 +1521,14 @@ mod tests {
     fn test_fields_mix() {
         let resources: Vec<Resource<u8>> = vec![
             Resource {
-                flavor: ResourceFlavor::Module,
                 name: Cow::from("foo"),
+                is_python_module: true,
                 in_memory_source: Some(Cow::from(b"import io".to_vec())),
                 ..Resource::default()
             },
             Resource {
-                flavor: ResourceFlavor::Module,
                 name: Cow::from("bar"),
+                is_python_module: true,
                 in_memory_bytecode: Some(Cow::from(b"fake bytecode".to_vec())),
                 ..Resource::default()
             },
