@@ -5,12 +5,13 @@
 /*! Serializing of structures into packed resources blobs. */
 
 use {
-    super::data::{
-        BlobInteriorPadding, BlobSectionField, Resource, ResourceField, ResourceFlavor, HEADER_V3,
+    crate::{
+        resource::Resource,
+        serialization::{BlobInteriorPadding, BlobSectionField, ResourceField, HEADER_V3},
     },
     anyhow::{anyhow, Context, Result},
     byteorder::{LittleEndian, WriteBytesExt},
-    std::{collections::BTreeMap, convert::TryFrom, io::Write, path::Path},
+    std::{collections::BTreeMap, io::Write, path::Path},
 };
 
 #[cfg(unix)]
@@ -112,8 +113,8 @@ where
     ///
     /// The resource is meaningful if it has data attached or is a package.
     pub fn is_meaningful(&self) -> bool {
-        self.is_package
-            || self.is_namespace_package
+        self.is_python_package
+            || self.is_python_namespace_package
             || self.in_memory_source.is_some()
             || self.in_memory_bytecode.is_some()
             || self.in_memory_bytecode_opt1.is_some()
@@ -138,19 +139,14 @@ where
         // Start of index entry.
         let mut index = 1;
 
-        if self.flavor != ResourceFlavor::None {
-            // Flavor field + value.
-            index += 2;
-        }
-
-        // Module name field + module length.
+        // Resource name field + name length.
         index += 3;
 
-        if self.is_package {
+        if self.is_python_package {
             index += 1;
         }
 
-        if self.is_namespace_package {
+        if self.is_python_namespace_package {
             index += 1;
         }
 
@@ -228,19 +224,19 @@ where
             index += 6 * metadata.len();
         }
 
-        if self.is_module {
+        if self.is_python_module {
             index += 1;
         }
 
-        if self.is_builtin_extension_module {
+        if self.is_python_builtin_extension_module {
             index += 1;
         }
 
-        if self.is_frozen_module {
+        if self.is_python_frozen_module {
             index += 1;
         }
 
-        if self.is_extension_module {
+        if self.is_python_extension_module {
             index += 1;
         }
 
@@ -278,10 +274,9 @@ where
             ResourceField::EndOfIndex => 0,
             ResourceField::StartOfEntry => 0,
             ResourceField::EndOfEntry => 0,
-            ResourceField::Flavor => 0,
-            ResourceField::ModuleName => self.name.as_bytes().len(),
-            ResourceField::IsPackage => 0,
-            ResourceField::IsNamespacePackage => 0,
+            ResourceField::Name => self.name.as_bytes().len(),
+            ResourceField::IsPythonPackage => 0,
+            ResourceField::IsPythonNamespacePackage => 0,
             ResourceField::InMemorySource => {
                 if let Some(source) = &self.in_memory_source {
                     source.len()
@@ -406,10 +401,10 @@ where
                     0
                 }
             }
-            ResourceField::IsModule => 0,
-            ResourceField::IsBuiltinExtensionModule => 0,
-            ResourceField::IsFrozenModule => 0,
-            ResourceField::IsExtensionModule => 0,
+            ResourceField::IsPythonModule => 0,
+            ResourceField::IsPythonBuiltinExtensionModule => 0,
+            ResourceField::IsPythonFrozenModule => 0,
+            ResourceField::IsPythonExtensionModule => 0,
             ResourceField::IsSharedLibrary => 0,
             ResourceField::IsUtf8FilenameData => 0,
             ResourceField::FileExecutable => 0,
@@ -440,10 +435,9 @@ where
             ResourceField::EndOfIndex => 0,
             ResourceField::StartOfEntry => 0,
             ResourceField::EndOfEntry => 0,
-            ResourceField::Flavor => 0,
-            ResourceField::ModuleName => 1,
-            ResourceField::IsPackage => 0,
-            ResourceField::IsNamespacePackage => 0,
+            ResourceField::Name => 1,
+            ResourceField::IsPythonPackage => 0,
+            ResourceField::IsPythonNamespacePackage => 0,
             ResourceField::InMemorySource => {
                 if self.in_memory_source.is_some() {
                     1
@@ -556,10 +550,10 @@ where
                     0
                 }
             }
-            ResourceField::IsModule => 0,
-            ResourceField::IsBuiltinExtensionModule => 0,
-            ResourceField::IsFrozenModule => 0,
-            ResourceField::IsExtensionModule => 0,
+            ResourceField::IsPythonModule => 0,
+            ResourceField::IsPythonBuiltinExtensionModule => 0,
+            ResourceField::IsPythonFrozenModule => 0,
+            ResourceField::IsPythonExtensionModule => 0,
             ResourceField::IsSharedLibrary => 0,
             ResourceField::IsUtf8FilenameData => 0,
             ResourceField::FileExecutable => 0,
@@ -587,7 +581,7 @@ where
         elements_count * overhead
     }
 
-    /// Write the version 1 index entry for a module instance.
+    /// Write the version 1 index entry for a resource instance.
     pub fn write_index_v1<W: Write>(&self, dest: &mut W) -> Result<()> {
         let name_len =
             u16::try_from(self.name.as_bytes().len()).context("converting name to u16")?;
@@ -595,26 +589,19 @@ where
         dest.write_u8(ResourceField::StartOfEntry.into())
             .context("writing start of index entry")?;
 
-        if self.flavor != ResourceFlavor::None {
-            dest.write_u8(ResourceField::Flavor.into())
-                .context("writing flavor field")?;
-            dest.write_u8(self.flavor.into())
-                .context("writing flavor value")?;
-        }
-
-        dest.write_u8(ResourceField::ModuleName.into())
-            .context("writing module name field")?;
+        dest.write_u8(ResourceField::Name.into())
+            .context("writing resource name field")?;
 
         dest.write_u16::<LittleEndian>(name_len)
-            .context("writing module name length")?;
+            .context("writing resource name length")?;
 
-        if self.is_package {
-            dest.write_u8(ResourceField::IsPackage.into())
+        if self.is_python_package {
+            dest.write_u8(ResourceField::IsPythonPackage.into())
                 .context("writing is_package field")?;
         }
 
-        if self.is_namespace_package {
-            dest.write_u8(ResourceField::IsNamespacePackage.into())
+        if self.is_python_namespace_package {
+            dest.write_u8(ResourceField::IsPythonNamespacePackage.into())
                 .context("writing is_namespace field")?;
         }
 
@@ -809,23 +796,23 @@ where
             }
         }
 
-        if self.is_module {
-            dest.write_u8(ResourceField::IsModule.into())
+        if self.is_python_module {
+            dest.write_u8(ResourceField::IsPythonModule.into())
                 .context("writing is_module field")?;
         }
 
-        if self.is_builtin_extension_module {
-            dest.write_u8(ResourceField::IsBuiltinExtensionModule.into())
+        if self.is_python_builtin_extension_module {
+            dest.write_u8(ResourceField::IsPythonBuiltinExtensionModule.into())
                 .context("writing is_builtin_extension_module field")?;
         }
 
-        if self.is_frozen_module {
-            dest.write_u8(ResourceField::IsFrozenModule.into())
+        if self.is_python_frozen_module {
+            dest.write_u8(ResourceField::IsPythonFrozenModule.into())
                 .context("writing is_frozen_module field")?;
         }
 
-        if self.is_extension_module {
-            dest.write_u8(ResourceField::IsExtensionModule.into())
+        if self.is_python_extension_module {
+            dest.write_u8(ResourceField::IsPythonExtensionModule.into())
                 .context("writing is_extension_module field")?;
         }
 
@@ -872,7 +859,7 @@ where
 /// Write packed resources data, version 3.
 #[allow(clippy::cognitive_complexity)]
 pub fn write_packed_resources_v3<'a, T: AsRef<Resource<'a, u8>>, W: Write>(
-    modules: &[T],
+    resources: &[T],
     dest: &mut W,
     interior_padding: Option<BlobInteriorPadding>,
 ) -> Result<()> {
@@ -883,7 +870,7 @@ pub fn write_packed_resources_v3<'a, T: AsRef<Resource<'a, u8>>, W: Write>(
     let mut blob_index_length = 1;
 
     // 1 for end of index field.
-    let mut module_index_length = 1;
+    let mut resource_index_length = 1;
 
     let process_field = |blob_sections: &mut BTreeMap<ResourceField, BlobSection>,
                          resource: &Resource<u8>,
@@ -915,87 +902,95 @@ pub fn write_packed_resources_v3<'a, T: AsRef<Resource<'a, u8>>, W: Write>(
         Ok(())
     };
 
-    for module in modules {
-        let module = module.as_ref();
-        module_index_length += module.index_v1_length();
+    for resource in resources {
+        let resource = resource.as_ref();
+        resource_index_length += resource.index_v1_length();
 
-        process_field(&mut blob_sections, module, ResourceField::ModuleName);
-        process_field(&mut blob_sections, module, ResourceField::InMemorySource);
-        process_field(&mut blob_sections, module, ResourceField::InMemoryBytecode);
+        process_field(&mut blob_sections, resource, ResourceField::Name);
+        process_field(&mut blob_sections, resource, ResourceField::InMemorySource);
         process_field(
             &mut blob_sections,
-            module,
+            resource,
+            ResourceField::InMemoryBytecode,
+        );
+        process_field(
+            &mut blob_sections,
+            resource,
             ResourceField::InMemoryBytecodeOpt1,
         );
         process_field(
             &mut blob_sections,
-            module,
+            resource,
             ResourceField::InMemoryBytecodeOpt2,
         );
         process_field(
             &mut blob_sections,
-            module,
+            resource,
             ResourceField::InMemoryExtensionModuleSharedLibrary,
         );
         process_field(
             &mut blob_sections,
-            module,
+            resource,
             ResourceField::InMemoryResourcesData,
         );
         process_field(
             &mut blob_sections,
-            module,
+            resource,
             ResourceField::InMemoryDistributionResource,
         );
         process_field(
             &mut blob_sections,
-            module,
+            resource,
             ResourceField::InMemorySharedLibrary,
         );
         process_field(
             &mut blob_sections,
-            module,
+            resource,
             ResourceField::SharedLibraryDependencyNames,
         );
         process_field(
             &mut blob_sections,
-            module,
+            resource,
             ResourceField::RelativeFilesystemModuleSource,
         );
         process_field(
             &mut blob_sections,
-            module,
+            resource,
             ResourceField::RelativeFilesystemModuleBytecode,
         );
         process_field(
             &mut blob_sections,
-            module,
+            resource,
             ResourceField::RelativeFilesystemModuleBytecodeOpt1,
         );
         process_field(
             &mut blob_sections,
-            module,
+            resource,
             ResourceField::RelativeFilesystemModuleBytecodeOpt2,
         );
         process_field(
             &mut blob_sections,
-            module,
+            resource,
             ResourceField::RelativeFilesystemExtensionModuleSharedLibrary,
         );
         process_field(
             &mut blob_sections,
-            module,
+            resource,
             ResourceField::RelativeFilesystemPackageResources,
         );
         process_field(
             &mut blob_sections,
-            module,
+            resource,
             ResourceField::RelativeFilesystemDistributionResource,
         );
-        process_field(&mut blob_sections, module, ResourceField::FileDataEmbedded);
         process_field(
             &mut blob_sections,
-            module,
+            resource,
+            ResourceField::FileDataEmbedded,
+        );
+        process_field(
+            &mut blob_sections,
+            resource,
             ResourceField::FileDataUtf8RelativePath,
         );
     }
@@ -1009,8 +1004,8 @@ pub fn write_packed_resources_v3<'a, T: AsRef<Resource<'a, u8>>, W: Write>(
 
     dest.write_u8(blob_section_count)?;
     dest.write_u32::<LittleEndian>(blob_index_length as u32)?;
-    dest.write_u32::<LittleEndian>(modules.len() as u32)?;
-    dest.write_u32::<LittleEndian>(module_index_length as u32)?;
+    dest.write_u32::<LittleEndian>(resources.len() as u32)?;
+    dest.write_u32::<LittleEndian>(resource_index_length as u32)?;
 
     // Write the blob index.
     for section in blob_sections.values() {
@@ -1019,54 +1014,54 @@ pub fn write_packed_resources_v3<'a, T: AsRef<Resource<'a, u8>>, W: Write>(
     dest.write_u8(ResourceField::EndOfIndex.into())?;
 
     // Write the resources index.
-    for module in modules {
-        module.as_ref().write_index_v1(dest)?;
+    for resource in resources {
+        resource.as_ref().write_index_v1(dest)?;
     }
     dest.write_u8(ResourceField::EndOfIndex.into())?;
 
     // Write blob data, one field at a time.
-    for module in modules {
-        dest.write_all(module.as_ref().name.as_bytes())?;
+    for resource in resources {
+        dest.write_all(resource.as_ref().name.as_bytes())?;
         add_interior_padding(dest)?;
     }
 
-    for module in modules {
-        if let Some(data) = &module.as_ref().in_memory_source {
+    for resource in resources {
+        if let Some(data) = &resource.as_ref().in_memory_source {
             dest.write_all(data)?;
             add_interior_padding(dest)?;
         }
     }
 
-    for module in modules {
-        if let Some(data) = &module.as_ref().in_memory_bytecode {
+    for resource in resources {
+        if let Some(data) = &resource.as_ref().in_memory_bytecode {
             dest.write_all(data)?;
             add_interior_padding(dest)?;
         }
     }
 
-    for module in modules {
-        if let Some(data) = &module.as_ref().in_memory_bytecode_opt1 {
+    for resource in resources {
+        if let Some(data) = &resource.as_ref().in_memory_bytecode_opt1 {
             dest.write_all(data)?;
             add_interior_padding(dest)?;
         }
     }
 
-    for module in modules {
-        if let Some(data) = &module.as_ref().in_memory_bytecode_opt2 {
+    for resource in resources {
+        if let Some(data) = &resource.as_ref().in_memory_bytecode_opt2 {
             dest.write_all(data)?;
             add_interior_padding(dest)?;
         }
     }
 
-    for module in modules {
-        if let Some(data) = &module.as_ref().in_memory_extension_module_shared_library {
+    for resource in resources {
+        if let Some(data) = &resource.as_ref().in_memory_extension_module_shared_library {
             dest.write_all(data)?;
             add_interior_padding(dest)?;
         }
     }
 
-    for module in modules {
-        if let Some(resources) = &module.as_ref().in_memory_package_resources {
+    for resource in resources {
+        if let Some(resources) = &resource.as_ref().in_memory_package_resources {
             for (key, value) in resources.iter() {
                 dest.write_all(key.as_bytes())?;
                 add_interior_padding(dest)?;
@@ -1076,8 +1071,8 @@ pub fn write_packed_resources_v3<'a, T: AsRef<Resource<'a, u8>>, W: Write>(
         }
     }
 
-    for module in modules {
-        if let Some(resources) = &module.as_ref().in_memory_distribution_resources {
+    for resource in resources {
+        if let Some(resources) = &resource.as_ref().in_memory_distribution_resources {
             for (key, value) in resources {
                 dest.write_all(key.as_bytes())?;
                 add_interior_padding(dest)?;
@@ -1087,15 +1082,15 @@ pub fn write_packed_resources_v3<'a, T: AsRef<Resource<'a, u8>>, W: Write>(
         }
     }
 
-    for module in modules {
-        if let Some(data) = &module.as_ref().in_memory_shared_library {
+    for resource in resources {
+        if let Some(data) = &resource.as_ref().in_memory_shared_library {
             dest.write_all(data)?;
             add_interior_padding(dest)?;
         }
     }
 
-    for module in modules {
-        if let Some(names) = &module.as_ref().shared_library_dependency_names {
+    for resource in resources {
+        if let Some(names) = &resource.as_ref().shared_library_dependency_names {
             for name in names {
                 dest.write_all(name.as_bytes())?;
                 add_interior_padding(dest)?;
@@ -1103,36 +1098,36 @@ pub fn write_packed_resources_v3<'a, T: AsRef<Resource<'a, u8>>, W: Write>(
         }
     }
 
-    for module in modules {
-        if let Some(path) = &module.as_ref().relative_path_module_source {
+    for resource in resources {
+        if let Some(path) = &resource.as_ref().relative_path_module_source {
             dest.write_all(&path_to_bytes(path))?;
             add_interior_padding(dest)?;
         }
     }
 
-    for module in modules {
-        if let Some(path) = &module.as_ref().relative_path_module_bytecode {
+    for resource in resources {
+        if let Some(path) = &resource.as_ref().relative_path_module_bytecode {
             dest.write_all(&path_to_bytes(path))?;
             add_interior_padding(dest)?;
         }
     }
 
-    for module in modules {
-        if let Some(path) = &module.as_ref().relative_path_module_bytecode_opt1 {
+    for resource in resources {
+        if let Some(path) = &resource.as_ref().relative_path_module_bytecode_opt1 {
             dest.write_all(&path_to_bytes(path))?;
             add_interior_padding(dest)?;
         }
     }
 
-    for module in modules {
-        if let Some(path) = &module.as_ref().relative_path_module_bytecode_opt2 {
+    for resource in resources {
+        if let Some(path) = &resource.as_ref().relative_path_module_bytecode_opt2 {
             dest.write_all(&path_to_bytes(path))?;
             add_interior_padding(dest)?;
         }
     }
 
-    for module in modules {
-        if let Some(path) = &module
+    for resource in resources {
+        if let Some(path) = &resource
             .as_ref()
             .relative_path_extension_module_shared_library
         {
@@ -1141,8 +1136,8 @@ pub fn write_packed_resources_v3<'a, T: AsRef<Resource<'a, u8>>, W: Write>(
         }
     }
 
-    for module in modules {
-        if let Some(resources) = &module.as_ref().relative_path_package_resources {
+    for resource in resources {
+        if let Some(resources) = &resource.as_ref().relative_path_package_resources {
             for (key, path) in resources.iter() {
                 dest.write_all(key.as_bytes())?;
                 add_interior_padding(dest)?;
@@ -1152,8 +1147,8 @@ pub fn write_packed_resources_v3<'a, T: AsRef<Resource<'a, u8>>, W: Write>(
         }
     }
 
-    for module in modules {
-        if let Some(resources) = &module.as_ref().relative_path_distribution_resources {
+    for resource in resources {
+        if let Some(resources) = &resource.as_ref().relative_path_distribution_resources {
             for (key, path) in resources {
                 dest.write_all(key.as_bytes())?;
                 add_interior_padding(dest)?;
@@ -1163,15 +1158,15 @@ pub fn write_packed_resources_v3<'a, T: AsRef<Resource<'a, u8>>, W: Write>(
         }
     }
 
-    for module in modules {
-        if let Some(data) = &module.as_ref().file_data_embedded {
+    for resource in resources {
+        if let Some(data) = &resource.as_ref().file_data_embedded {
             dest.write_all(data)?;
             add_interior_padding(dest)?;
         }
     }
 
-    for module in modules {
-        if let Some(path) = &module.as_ref().file_data_utf8_relative_path {
+    for resource in resources {
+        if let Some(path) = &resource.as_ref().file_data_utf8_relative_path {
             dest.write_all(path.as_bytes())?;
             add_interior_padding(dest)?;
         }
@@ -1182,7 +1177,7 @@ pub fn write_packed_resources_v3<'a, T: AsRef<Resource<'a, u8>>, W: Write>(
 
 #[cfg(test)]
 mod tests {
-    use {super::*, crate::data::ResourceFlavor, std::borrow::Cow};
+    use {super::*, std::borrow::Cow};
 
     #[test]
     fn test_write_empty() -> Result<()> {
@@ -1195,7 +1190,7 @@ mod tests {
         expected.write_u8(0)?;
         // Length of blob index (end of index marker).
         expected.write_u32::<LittleEndian>(1)?;
-        // Number of modules.
+        // Number of resources.
         expected.write_u32::<LittleEndian>(0)?;
         // Lenght of index (end of index marker).
         expected.write_u32::<LittleEndian>(1)?;
@@ -1209,39 +1204,36 @@ mod tests {
     }
 
     #[test]
-    fn test_write_module_name() -> Result<()> {
+    fn test_write_resource_name() -> Result<()> {
         let mut data = Vec::new();
-        let module = Resource {
-            flavor: ResourceFlavor::Module,
+        let resource = Resource {
             name: Cow::Owned("foo".to_string()),
             ..Resource::default()
         };
 
-        write_packed_resources_v3(&[module], &mut data, None)?;
+        write_packed_resources_v3(&[resource], &mut data, None)?;
 
         let mut expected: Vec<u8> = b"pyembed\x03".to_vec();
         // Number of blob sections.
         expected.write_u8(1)?;
         // Length of blob index. Start of entry, field type, field value, length field, length, end of entry, end of index.
         expected.write_u32::<LittleEndian>(1 + 1 + 1 + 1 + 8 + 1 + 1)?;
-        // Number of modules.
+        // Number of resources.
         expected.write_u32::<LittleEndian>(1)?;
-        // Length of index. Start of entry, flavor field, flavor value, module name length field,
-        // module name length, end of entry, end of index.
-        expected.write_u32::<LittleEndian>(1 + 1 + 1 + 1 + 2 + 1 + 1)?;
+        // Length of index. Start of entry, flavor field, flavor value, resource name length field,
+        // resource name length, end of entry, end of index.
+        expected.write_u32::<LittleEndian>(1 + 1 + 2 + 1 + 1)?;
         // Blobs index.
         expected.write_u8(BlobSectionField::StartOfEntry.into())?;
         expected.write_u8(BlobSectionField::ResourceFieldType.into())?;
-        expected.write_u8(ResourceField::ModuleName.into())?;
+        expected.write_u8(ResourceField::Name.into())?;
         expected.write_u8(BlobSectionField::RawPayloadLength.into())?;
         expected.write_u64::<LittleEndian>(b"foo".len() as u64)?;
         expected.write_u8(BlobSectionField::EndOfEntry.into())?;
         expected.write_u8(BlobSectionField::EndOfIndex.into())?;
-        // Module index.
+        // Resource index.
         expected.write_u8(ResourceField::StartOfEntry.into())?;
-        expected.write_u8(ResourceField::Flavor.into())?;
-        expected.write_u8(ResourceFlavor::Module.into())?;
-        expected.write_u8(ResourceField::ModuleName.into())?;
+        expected.write_u8(ResourceField::Name.into())?;
         expected.write_u16::<LittleEndian>(b"foo".len() as u16)?;
         expected.write_u8(ResourceField::EndOfEntry.into())?;
         expected.write_u8(ResourceField::EndOfIndex.into())?;
